@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2025  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As an exception, when this program is distributed through (i) the App Store
  * by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or (iii) Google Play
@@ -42,6 +42,7 @@
 
 #ifdef NMZ_FLINT
 #include "flint/flint.h"
+#include "flint/fmpz.h"
 #include "flint/fmpz_poly.h"
 #endif
 
@@ -72,7 +73,10 @@ void flint_poly(fmpz_poly_t flp, const vector<mpz_class>& nmzp) {
     slong n = (slong)nmzp.size();
     fmpz_poly_fit_length(flp, n);
     for (size_t i = 0; i < nmzp.size(); ++i) {
-        fmpz_poly_set_coeff_mpz(flp, (slong)i, nmzp[i].get_mpz_t());
+        fmpz_t fc;
+        fmpz_init(fc);
+        fmpz_set_mpz(fc, nmzp[i].get_mpz_t());
+        fmpz_poly_set_coeff_fmpz(flp, (slong)i, fc);
     }
 }
 
@@ -80,9 +84,12 @@ void nmz_poly(vector<mpz_class>& nmzp, const fmpz_poly_t flp) {
     size_t n = (size_t)fmpz_poly_length(flp);
     nmzp.resize(n);
     mpz_t c;
+    fmpz_t fc;
     mpz_init(c);
+    fmpz_init(fc);
     for (size_t i = 0; i < nmzp.size(); ++i) {
-        fmpz_poly_get_coeff_mpz(c, flp, i);
+        fmpz_poly_get_coeff_fmpz(fc, flp, i);
+        fmpz_get_mpz(c, fc);
         nmzp[i] = mpz_class(c);
     }
     mpz_clear(c);
@@ -145,7 +152,7 @@ void poly_div(vector<Integer>& q, vector<Integer>& r, const vector<Integer>& a,
     r = a;
     remove_zeros(r);
     size_t b_size = b.size();
-    int degdiff = r.size() - b_size;  // degree differenz
+    size_t degdiff = r.size() - b_size;  // degree differenz
     if (r.size() < b_size) {
         q = vector<Integer>();
     }
@@ -294,6 +301,8 @@ void HilbertSeries::initialize() {
     nr_coeff_quasipol = -1;  // all coefficients
     expansion_degree = -1;
     period_bounded = true;
+    only_cyclotomic = false;
+    allow_quasipoly = true;
 }
 
 // Constructor, creates 0/1
@@ -303,6 +312,10 @@ HilbertSeries::HilbertSeries() {
     initialize();
 }
 
+void HilbertSeries::set_to_one(){
+        num = vector<mpz_class>(1, 1);
+}
+
 // Constructor, creates num/denom, see class description for format
 HilbertSeries::HilbertSeries(const vector<num_t>& numerator, const vector<denom_t>& gen_degrees) {
     num = vector<mpz_class>(1, 0);
@@ -317,7 +330,21 @@ HilbertSeries::HilbertSeries(const vector<mpz_class>& numerator, const map<long,
     initialize();
 }
 
-/* 
+HilbertSeries::HilbertSeries(const vector<mpz_class>& numerator, const vector<denom_t> given_denom) {
+
+    map<long, denom_t> denominator;
+    for(size_t i = 0; i < given_denom.size(); ++i){
+        if(denominator.find(given_denom[i]) == denominator.end())
+            denominator[given_denom[i]] = 1;
+        else
+            denominator[given_denom[i]]++;
+    }
+    num = numerator;
+    denom = denominator;
+    initialize();
+}
+
+/*
 // Constructor, string as created by to_string_rep
 HilbertSeries::HilbertSeries(const string& str) {
     from_string_rep(str);
@@ -349,6 +376,32 @@ void HilbertSeries::set_period_bounded(bool on_off) const {  // period_bounded i
 bool HilbertSeries::get_period_bounded() const {
     return period_bounded;
 }
+
+void HilbertSeries::set_only_cyclotomic(bool on_off) const{
+    only_cyclotomic = on_off;
+}
+
+bool HilbertSeries::get_only_cyclotomic() const{
+    return only_cyclotomic;
+}
+
+void HilbertSeries::forbid_quasipol(bool on_off) const{
+    allow_quasipoly = !on_off;
+}
+
+bool HilbertSeries::get_quasipol_allowed() const{
+    return allow_quasipoly;
+}
+
+void HilbertSeries::get_variants(const HilbertSeries& mother){
+    set_expansion_degree(mother.get_expansion_degree());
+    set_nr_coeff_quasipol(mother.get_nr_coeff_quasipol());
+    forbid_quasipol(!mother.get_quasipol_allowed());
+    set_only_cyclotomic(mother.get_only_cyclotomic());
+    set_period_bounded(mother.get_period_bounded());
+    //HSOP is extra
+}
+
 // add another HilbertSeries to this
 void HilbertSeries::add(const vector<num_t>& num, const vector<denom_t>& gen_degrees) {
     vector<denom_t> sorted_gd(gen_degrees);
@@ -432,12 +485,31 @@ void HilbertSeries::collectData() const {
 
 // simplify, see class description
 void HilbertSeries::simplify() const {
+
     if (is_simplified)
         return;
     collectData();
-    /*    if (verbose) {
+
+    size_t highest_comp = num.size();
+    bool non_zero = false;
+    // First we remove "leading" 0 from the numerator
+    for(size_t i = 0; i < num.size(); ++i){
+        if(num[i] != 0){
+            highest_comp = i;
+            non_zero = true;
+        }
+    }
+    if(non_zero)
+        num.resize(highest_comp + 1);
+    else
+        num.clear();
+
+    computeDegreeAsRationalFunction();
+
+    /*if (verbose) {
             verboseOutput() << "Hilbert series before simplification: "<< endl << *this;
-        }*/
+        }
+    */
     vector<mpz_class> q, r, poly;  // polynomials
     // In denom_cyclo we collect cyclotomic polynomials in the denominator.
     // During this method the Hilbert series is given by num/(denom*cdenom)
@@ -455,7 +527,7 @@ void HilbertSeries::simplify() const {
         poly = coeff_vector<mpz_class>(i);
         while (denom_i > 0) {
             poly_div(q, r, num, poly);
-            if (r.size() == 0) {  // numerator is divisable by poly
+            if (r.size() == 0) {  // numerator is divisible by poly
                 num = q;
                 denom_i--;
             }
@@ -465,7 +537,6 @@ void HilbertSeries::simplify() const {
         }
         if (denom_i == 0)
             continue;
-
         // decompose (1-t^i) into cyclotomic polynomial
         for (long d = 1; d <= i / 2; ++d) {
             if (i % d == 0)
@@ -476,6 +547,7 @@ void HilbertSeries::simplify() const {
         if (denom_i % 2 == 1)
             v_scalar_multiplication(num, mpz_class(-1));
     }  // end for
+
     denom.clear();
 
     auto it = cdenom.begin();
@@ -489,7 +561,7 @@ void HilbertSeries::simplify() const {
         poly = cyclotomicPoly<mpz_class>(i);
         while (cyclo_i > 0) {
             poly_div(q, r, num, poly);
-            if (r.empty()) {  // numerator is divisable by poly
+            if (r.empty()) {  // numerator is divisible by poly
                 num = q;
                 cyclo_i--;
             }
@@ -510,13 +582,23 @@ void HilbertSeries::simplify() const {
     cyclo_num = num;
     cyclo_denom = cdenom;
 
+    period = lcm_of_keys(cdenom);
+
+    if(only_cyclotomic){
+        expansion_degree = -1;
+        nr_coeff_quasipol = 0;
+        num.clear();
+        denom.clear();
+        is_simplified = true;
+        return;
+    }
+
     // now collect the cyclotomic polynomials in (1-t^i) factors
     it = cdenom.find(1);
     if (it != cdenom.end())
-        dim = it->second;
+        dim = it->second; // dim = number of occurrences of 1
     else
         dim = 0;
-    period = lcm_of_keys(cdenom);
     if (period_bounded && period > 10 * PERIOD_BOUND) {
         if (verbose) {
             errorOutput() << "WARNING: Period is too big, the representation of the Hilbert series may have more than dimension "
@@ -566,12 +648,11 @@ void HilbertSeries::simplify() const {
         }
     }
     is_simplified = true;
-    computeDegreeAsRationalFunction();
     quasi_poly.clear();
 }
 
 void HilbertSeries::computeDegreeAsRationalFunction() const {
-    simplify();
+    // simplify();
     long num_deg = num.size() - 1 + shift;
     long denom_deg = 0;
     for (auto& it : denom) {
@@ -613,14 +694,14 @@ mpz_class HilbertSeries::getHilbertQuasiPolynomialDenom() const {
 }
 
 void HilbertSeries::computeHilbertQuasiPolynomial() const {
-    if (isHilbertQuasiPolynomialComputed() || nr_coeff_quasipol == 0)
+    if (isHilbertQuasiPolynomialComputed() || !allow_quasipoly)
         return;
     simplify();
 
     vector<long> denom_vec = to_vector(denom);
     if (nr_coeff_quasipol > (long)denom_vec.size()) {
         if (verbose)
-            verboseOutput() << "Number of coeff of quasipol too large. Reset to deault value." << endl;
+            verboseOutput() << "Number of coeff of quasipol too large. Reset to default value." << endl;
         nr_coeff_quasipol = -1;
     }
 
@@ -633,7 +714,7 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
         return;
     }
     if (verbose && period > 1) {
-        verboseOutput() << "Computing Hilbert quasipolynomial of period " << period << " ..." << flush;
+        verboseOutput() << "Computing quasipolynomial of period " << period << " ..." << flush;
     }
     long i, j;
     // period und dim encode the denominator
@@ -690,11 +771,11 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
     for (j = 0; j < reduced_period; ++j) {
         INTERRUPT_COMPUTATION_BY_EXCEPTION
 
-        quasi_poly[j] = compute_polynomial(quasi_poly[j], dim);
+        quasi_poly[j] = compute_polynomial(quasi_poly[j], static_cast<int>(dim));
     }
 
     // substitute t by t/period:
-    // dividing by period^dim and multipling the coeff with powers of period
+    // dividing by period^dim and multiplying the coeff with powers of period
     mpz_class pp = 1;
     for (i = dim - 2; i >= 0; --i) {
         pp *= period;  // p^i   ok, it is p^(dim-1-i)
@@ -715,7 +796,7 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
     g = libnormaliz::gcd(g, quasi_denom);
     quasi_denom /= g;
     QP.scalar_division(g);
-    // we use a normed shift, so that the cylcic shift % period always yields a non-negative integer
+    // we use a normed shift, so that the cyclic shift % period always yields a non-negative integer
     long normed_shift = -shift;
     while (normed_shift < 0)
         normed_shift += reduced_period;
@@ -849,7 +930,21 @@ void HilbertSeries::adjustShift() {
     }
 }
 
-/*
+ void HilbertSeries::increase_shift(const int d){
+     assert( d >= 0);
+     num.insert(num.begin(),d,0);
+     if(cyclo_num.size() > 0)
+        cyclo_num.insert(cyclo_num.begin(),0);
+ }
+
+ void HilbertSeries::multiply_denom(const int d){
+        assert(d > 0);
+        if(denom.find(d) != denom.end())
+            denom[d]+=1;
+        else
+            denom[d] = 1;
+ }
+
 // methods for textual transfer of a Hilbert Series
 string HilbertSeries::to_string_rep() const {
     collectData();
@@ -914,7 +1009,7 @@ ostream& operator<<(ostream& out, const HilbertSeries& HS) {
     out << " )" << std::endl;
     return out;
 }
-*/
+
 
 //---------------------------------------------------------------------------
 // polynomial operations, for polynomials repr. as vector of coefficients
@@ -1111,7 +1206,7 @@ vector<Integer> compute_e_vector(vector<Integer> Q, int dim) {
     vector<Integer> E_Vector(dim, 0);
     // cout << "QQQ " << Q;
     // Q.resize(dim+1);
-    int bound = Q.size();
+    int bound = static_cast<int>(Q.size());
     if (bound > dim)
         bound = dim;
     for (i = 0; i < bound; i++) {
@@ -1120,7 +1215,7 @@ vector<Integer> compute_e_vector(vector<Integer> Q, int dim) {
         }
         E_Vector[i] /= permutations<Integer>(1, i);
         for (j = 1; j < Q.size() - i; j++) {
-            Q[j - 1] = j * Q[j];
+            Q[j - 1] = static_cast<unsigned long>(j) * Q[j];
         }
     }
     return E_Vector;
