@@ -62,6 +62,8 @@ public:
     vector<key_t> duality;
     vector<key_t> subring_base_key;
 
+    vector<renf_elem_class> renf_fusion_type; // used to circumvent mising renf_class
+
     double total_FPdim;
 
     vector<vector<dynamic_bitset> > ModularGradings;
@@ -73,8 +75,8 @@ public:
     vector<key_t> fusion_image_type;
     vector<key_t> fusion_image_duality;
     string fusion_image_type_string;
-    vector<long> fusion_image_ring;
-    Matrix<long> fusion_ring_map;
+    vector<long long> fusion_image_ring;
+    Matrix<long long> fusion_ring_map;
     bool fusion_image_commutative;
 
     vector<vector<shortkey_t> > type_automs; // permutations of the basis vectors
@@ -105,6 +107,8 @@ public:
     bool compatible_duality(const vector<dynamic_bitset >& parts);
     void make_grad_mult_table();
     void restrict_type_automs_to_grading();
+    template <typename Integer>
+    void set_renf_fusion_type(const vector<Integer>&);
 
     void make_type_automs();
 };
@@ -265,6 +269,18 @@ void string_to_type(vector<Integer>& our_type, const string& our_type_string){
     }
 }
 
+/*
+#ifdef ENFNORMALIZ
+inline void string_to_type(vector<renf_elem_class>& our_type, const string& our_type_string){
+
+    istringstream type_stram(our_type_string);
+    for(size_t i = 0; i < our_type.size(); ++i){
+        type_stram >> our_type[i];
+    }
+}
+#endif
+*/
+
 template <typename Integer>
 vector<key_t> fusion_coincidence_pattern(const vector<Integer>& v);
 
@@ -284,11 +300,22 @@ bool check_duality(vector<Integer> test_duality, const vector<Integer>& test_typ
     return true;
 }
 
+template <typename Integer>
+void FusionBasic::set_renf_fusion_type(const vector<Integer>& full_type){
+
+}
+
+template <>
+inline void FusionBasic::set_renf_fusion_type(const vector<renf_elem_class>& full_type){
+    renf_fusion_type = full_type;
+}
+
 // Note: the following routine must work for renf_elem_class
 template <typename Integer>
 void FusionBasic::read_data_from_input(InputMap<Integer>& input_data){
 
     vector<Integer> full_type = input_data[Type::fusion_type][0];
+    set_renf_fusion_type<Integer>(full_type);
     total_FPdim = 0;
     for(size_t i = 0; i< full_type.size(); ++i){
         double this_FPdim;
@@ -308,6 +335,8 @@ void FusionBasic::read_data_from_input(InputMap<Integer>& input_data){
 
     commutative = false;
     if(contains(input_data, Type::fusion_duality)){
+        if(input_data[Type::fusion_duality].nr_of_rows() == 0)
+            throw BadInputException("Empty fusion duality");
         vector<Integer> prel_duality = input_data[Type::fusion_duality][0];
         // std::cout << "PREL " << prel_duality; //" -- " << prel_duality.size() << " -- " <<  fusion_rank_from_input << endl;
         if(prel_duality.size() != fusion_rank || (prel_duality[0] != 0 && prel_duality[0] != -1 && prel_duality[0] != -2 && prel_duality[0] != -3))
@@ -323,19 +352,12 @@ void FusionBasic::read_data_from_input(InputMap<Integer>& input_data){
             use_modular_grading = true;
             prel_duality[0] = 0;
         }
-        duality.resize(fusion_rank);
-        for(key_t i = 0; i < fusion_rank; ++i){
-            bool in_range = false;
-            for(long j = 0; j < fusion_rank; ++j){  // conversion by counting
-                if(convertTo<Integer>(j) == prel_duality[i]){
-                    duality[i] = j;
-                    in_range = true;
-                    break;
-                }
-            }
-            if(!in_range)
-                throw BadInputException("Fusion duality out of range");
+        convert_vector_via_string(duality, prel_duality);
+        for(size_t i = 0; i < fusion_rank; ++i){
+            if(duality[i] > fusion_rank)
+               throw BadInputException("Fusion duality out of range");
         }
+
         if(key_to_bitset(duality, fusion_rank).count() != fusion_rank)
             throw BadInputException("Fusion duality has repeated entries");
         if(!check_duality<key_t>(duality, fusion_type))
@@ -386,8 +408,9 @@ void FusionBasic::read_data_from_input(InputMap<Integer>& input_data){
 
     if(!contains(input_data, Type::fusion_image_duality)){ // take the default
         input_data[Type::fusion_image_duality].resize(1);
-        convert_vector_via_string(input_data[Type::fusion_image_duality][0],
-                                  identity_key(fusion_ring_map.nr_of_columns()));
+        input_data[Type::fusion_image_duality][0].resize(fusion_ring_map.nr_of_columns());
+        for(long i = 0; i < fusion_ring_map.nr_of_columns(); ++i)
+            input_data[Type::fusion_image_duality][0][i] = i;
     }
 
     InputMap<Integer> Help;
@@ -413,16 +436,9 @@ void FusionBasic::read_data_from_input(InputMap<Integer>& input_data){
         }
     }
 
-    vector<long> full_image_type(fusion_image_duality.size());
-    string our_type_string = fusion_image_type_string;
-    string_to_type(full_image_type, our_type_string);
-
-    vector<long> full_type_long(duality.size());
-    convert_vector_via_string(full_type_long, full_type);
-
-    vector<long> test_type = fusion_ring_map.MxV(full_image_type);
-    if(test_type != full_type_long)
-        throw BadInputException("Fusion type does not fit fusion ring map");
+    vector<Integer> test_vector = input_data[Type::fusion_ring_map].MxV(input_data[Type::fusion_image_type][0]);
+    if(test_vector != input_data[Type::fusion_type][0])
+        throw BadInputException("Fusion types do not fit fusion ring map");
 }
 
 template <typename Integer>
@@ -431,6 +447,10 @@ void make_full_input(FusionBasic& FusionInput, InputMap<Integer>& input_data) {
     FusionInput.read_data_from_input(input_data);
     FusionComp<Integer> OurFusion(FusionInput);
     vector<Integer> full_type = input_data[Type::fusion_type][0];
+    // The following condition is true if we make an integer cone for
+    // the computation of fusion rings from a renf_elem_class cone
+    if(contains(input_data, Type::inhom_inequalities))
+        return;
     Matrix<Integer> Equ = OurFusion.make_linear_constraints(full_type);
     // FusionInput.type_aiutoms_mde = OurFusion.automorphisms_mde;
     // swap(FusionInput.Automorphisms,OurFusion.Automorphisms);
