@@ -46,6 +46,7 @@ public:
 
     bool mult_of_ev_ok;
     bool commutative;
+    bool near_integral;
 
     Matrix<Integer> F;
 
@@ -54,9 +55,12 @@ public:
     string fusion_type_string;
     vector<key_t> duality;
 
+    vector<vector<key_t > > type_automs;
+
     vector<Integer> ImageRing;
 
     Integer FPdim;
+    long long FPdim_S; // for near integral fusion rings
     Integer FPSquare;
 
     FusionBasic FusBasic;
@@ -64,17 +68,20 @@ public:
     vector<Matrix<Integer> >  Tables;
 
     vector<Integer> divisors;
+    vector<Integer> candidates_m_i;
     // In the next line the first size_t is the multiplicity, the second the n_i
     map<Integer,pair<size_t, size_t> > EV_mult_n_i;
     Matrix<Integer> EVMat;
 
+    // for the near-inegral case with minimal polynomial a^2 - kkk*a - FPdim_S
+    Integer kkk, d_plus, d_minus; // zeroes d_plus > 0 and d_minus < 0
+
     // first: the m_i for i < s = number of irreducible presentations
-    // second: the dimensions of the irreducibles as an Integer
-    vector<pair<Integer, Integer> > low_m;
+    // second: the dimensions of the irreducibles
+    vector<pair<Integer, long long> > low_m;
 
     vector<Matrix<Integer> > InductionMatrices;
-    vector<Matrix<Integer> > LowParts;
-    // vector<Matrix<Integer> > LowPartsBounds;
+    vector<Matrix<long long> > LowParts;
 
     size_t iupper_bound;
     size_t nr_rows_low_part; // = number of irreducibles
@@ -82,22 +89,37 @@ public:
     Integer N(const key_t i, const key_t j, const key_t k);
 
     // map< Integer, Matrix<Integer > > LowRepresentations;  // F_ij for i <= r (counting from 1), F_i1 = 1
-    Matrix<Integer > HighRepresentations; // F_ij for i > 1 (counting from 1), F_i1 = 0
-    Matrix<Integer> Bounds;
+    Matrix<long long> HighRepresentations; // F_ij for i > 1 (counting from 1), F_i1 = 0
+    Matrix<long long> HighRepsHere;
+    Matrix<Integer> Bounds_Int;
+    Matrix<long long> Bounds;
+    vector<string> BoundsPolys; // Bounds as polynomials
 
     Induction();
     Induction(const vector<Integer>& fus_type, const vector<key_t>& fus_duality , const vector<Integer>& FusRing, bool verb);
 
     void test_commutativity();
 
-    void eigenvalues_and_mult_commutative();
-    void eigenvalues_and_mult_noncommutative();
+    void codegrees_and_mult_commutative();
+    void codegrees_and_mult_noncommutative();
+    void codegrees_and_mult_near_integral();
 
     // void start_low_parts();
+    void make_divisors();
+    void make_divisors_near_integral();
+    void make_candidates_m_i();
+    void make_low_m_i();
     void build_low_parts();
     void solve_system_low_parts();
     void from_low_to_full();
     void augment_induction_matrices();
+    void high_parts_recursive(const Matrix<long long>& Remaining, size_t p, long start, const Matrix<long long>& Ind_so_far);
+
+    bool column_normal(const Matrix<long long>& mat) const;
+
+    Integer conjugate(const Integer& val);
+    //bool is_algebraic_integer(const Integer& val);
+    // bool is_algebraic_integer_old(const Integer& val);
 
     Matrix<Integer> make_allowed_transpositions(Matrix<Integer> FusionMap);
 
@@ -107,6 +129,9 @@ public:
 
 }; // class Induction end
 
+template<typename Integer>
+Matrix<long long> SplitRepresentation(Integer val, vector<Integer> summands);
+
 } // namespace
 
 #endif /* LIBNORMALIZ_INDUCTION_H */
