@@ -33,27 +33,9 @@
 namespace libnormaliz {
 
 //---------------------------------------------------------------------------
-//                     Number input
+//                     Number input (also see input.h)
 //---------------------------------------------------------------------------
 
-
-#ifdef ENFNORMALIZ
-
-static int xalloc = std::ios_base::xalloc();
-
-// Normaliz implementation of deprecated e-antic functions
-std::istream & nmz_set_pword(boost::intrusive_ptr<const renf_class> our_renf, std::istream & is)
-{
-    is.pword(xalloc) = const_cast<void*>(reinterpret_cast<const void*>(&*our_renf));
-    return is;
-}
-boost::intrusive_ptr<const renf_class> nmz_get_pword(std::istream& is) {
-    return reinterpret_cast<renf_class*>(is.pword(xalloc));
-}
-#endif
-//---------------------------------------------------------
-
-
 // To be used in input.cpp
 inline void string2coeff(mpq_class& coeff, istream& in, const string& s) {  // in here superfluous parameter
 
@@ -82,54 +64,6 @@ inline void read_number(istream& in, mpz_class& number) {
     in >> number;
 }
 
-#ifdef ENFNORMALIZ
-
-inline void string2coeff(renf_elem_class& coeff, istream& in, const string& s) {  // we need in to access the renf
-
-    try {
-        coeff = renf_elem_class(*nmz_get_pword(in), s);
-    } catch (const std::exception& e) {
-        cerr << e.what() << endl;
-        throw BadInputException("Illegal number string " + s + " in input, Exiting.");
-    }
-}
-
-inline void read_number(istream& in, renf_elem_class& number) {
-    // in >> number;
-
-    char c;
-
-    in >> ws;
-    c = in.peek();
-    if (c != '(' && c != '\'' && c != '\"') {  // rational number
-        mpq_class rat = mpq_read(in);
-        number = renf_elem_class(rat);
-        return;
-    }
-
-    // now we have a proper field element
-
-    in >> c;  // read (
-
-    string num_string;
-    bool skip = false;
-    while (in.good()) {
-        c = in.peek();
-        if (c == ')' || c == '\'' || c == '\"') {
-            in >> c;
-            break;
-        }
-        if (c == '~' || c == '=' || c == '[')  // skip the approximation
-            skip = true;
-        in.get(c);
-        if (in.fail())
-            throw BadInputException("Error in reading number: field element not terminated");
-        if (!skip)
-            num_string += c;
-    }
-    string2coeff(number, in, num_string);
-}
-#endif
 
 // matrix input
 
@@ -835,7 +769,7 @@ void read_number_field_strings(istream& in, string& mp_string, string& indet, st
 }
 
 #ifdef ENFNORMALIZ
-renf_class_shared read_number_field(istream& in) {
+renf_class_ptr read_number_field(istream& in) {
     string mp_string, indet, emb_string;
     read_number_field_strings(in, mp_string, indet, emb_string);
 
@@ -862,7 +796,7 @@ InputMap<Number> readNormalizInput(istream& in,
                                             map<NumParam::Param, long>& num_param_input,
                                             map<BoolParam::Param, bool>& bool_param_input,
                                             map<PolyParam::Param, vector<string> >& poly_param_input,
-                                            renf_class_shared& number_field) {
+                                            renf_class_ptr& number_field) {
     string type_string;
     long i, j;
     long nr_rows, nr_columns, nr_rows_or_columns;
@@ -1328,7 +1262,7 @@ template InputMap<mpq_class> readNormalizInput(istream& in,
                                                     map<NumParam::Param, long>& num_param_input,
                                                     map<BoolParam::Param, bool>& bool_param_input,
                                                     map<PolyParam::Param, vector<string> >& poly_param_input,
-                                                    renf_class_shared& number_field);
+                                                    renf_class_ptr& number_field);
 
 #ifdef ENFNORMALIZ
 template InputMap<renf_elem_class> readNormalizInput(istream& in,
@@ -1336,7 +1270,7 @@ template InputMap<renf_elem_class> readNormalizInput(istream& in,
                                                      map<NumParam::Param, long>& num_param_input,
                                                      map<BoolParam::Param, bool>& bool_param_input,
                                                      map<PolyParam::Param, vector<string> >& poly_param_input,
-                                                     renf_class_shared& number_field);
+                                                     renf_class_ptr& number_field);
 #endif
 
 #ifndef NMZ_MIC_OFFLOAD  // offload with long is not supported
