@@ -933,6 +933,26 @@ long SimplexParallelEvaluationBound = 100000000;  // simplices larger than this
 
 //---------------------------------------------------------------------------
 
+// Simplices can be treated in three ways:
+//
+// (1)  Complete evaluation in regard to all data in a single thread by
+//      evaluate(SHORTSIMPLEX<Integer>& s),
+//      provided volume < SimplexParallelEvaluationBound.
+//      This finction returns true in case of the evaluation, else false.
+//      As a consequence of false, the simplex is included in LargeSinmplicesBuffer
+//      in FullCone.cpp.
+//
+// (2)  By Simplex_parallel_evaluation, called from evaluate_large_simplices_inner
+//      in full_cone.cpp.The returned simplices are made pyramids of level 1.
+// (3)  As (2), but evaluating the simplex in parallel threads, if a subdivision is
+//      not possible or forbidden.
+//   See the functions evaluate or Simplex_parallel_evaluation for more details.
+//
+// The goal of this scheme is the efficient use of parallelization by OpenMP.
+//
+// A good demonstration file is Jupiter.in in example.
+//
+
 /* evaluates a simplex in regard to all data in a single thread*/
 template <typename Integer>
 bool SimplexEvaluator<Integer>::evaluate(SHORTSIMPLEX<Integer>& s) {
@@ -946,9 +966,8 @@ bool SimplexEvaluator<Integer>::evaluate(SHORTSIMPLEX<Integer>& s) {
     // large simplicies to be postponed for parallel evaluation
     if (volume > SimplexParallelEvaluationBound / 10
         // || (volume > SimplexParallelEvaluationBound/10 && C_ptr->do_Hilbert_basis) )
-        && !C_ptr->do_Stanley_dec && C_ptr->allow_simplex_dec
-    ) {  //&& omp_get_max_threads()>1)
-        return false;
+        && !C_ptr->do_Stanley_dec){
+            return false;
     }
     if (C_ptr->stop_after_cone_dec)
         return true;
@@ -957,8 +976,6 @@ bool SimplexEvaluator<Integer>::evaluate(SHORTSIMPLEX<Integer>& s) {
         evaluate_block(1, convertToLong(volume) - 1, C_ptr->Results[tn]);
     conclude_evaluation(C_ptr->Results[tn]);
 
-    // Simplex_parallel_evaluation(); TODO instead of not parallelized evaluation
-
     return true;
 }
 
@@ -1163,9 +1180,9 @@ void SimplexEvaluator<Integer>::Simplex_parallel_evaluation() {
     }
 
     if (C_ptr->allow_simplex_dec &&
-        (volume >= SimplexParallelEvaluationBound ||
-        (volume > SimplexParallelEvaluationBound / 10 && C_ptr->do_Hilbert_basis)) &&
-        (!C_ptr->deg1_triangulation || !C_ptr->isComputed(ConeProperty::Grading))) {  // try subdivision
+        (volume >= SimplexParallelEvaluationBound||
+        (volume > SimplexParallelEvaluationBound / 10 && C_ptr->do_Hilbert_basis))
+        &&   (!C_ptr->deg1_triangulation || !C_ptr->isComputed(ConeProperty::Grading))) {  // try subdivision
 
         Full_Cone<Integer>& C = *C_ptr;
 
@@ -1211,14 +1228,14 @@ void SimplexEvaluator<Integer>::Simplex_parallel_evaluation() {
             addMult(-volume, C.Results[0]);
             // delete this large simplex
             C.totalNrSimplices--;
-            if (C.keep_triangulation) {
+            /*if (C.keep_triangulation) {
                 for (auto it = C.Triangulation.begin(); it != C.Triangulation.end(); ++it) {
                     if (it->key == key) {
                         C.Triangulation.erase(it);
                         break;
                     }
                 }
-            }
+            }*/
 
             // create generators for bottom decomposition
             // we start with the extreme rays of the recession cone
