@@ -63,7 +63,7 @@ void printHeader() {
 #endif
     cout << "                                                       \\...|" << endl;
     cout << "     (C) The Normaliz Team, University of Osnabrueck    \\..|" << endl;
-    cout << "                      October  2025                      \\.|" << endl;
+    cout << "                     February  2026                      \\.|" << endl;
     cout << "                                                          \\|" << endl;
     string optional_packages = package_string();
     if (optional_packages.size() > 0) {
@@ -422,17 +422,19 @@ void compute_and_output(OptionsHandler& options,
                         const map<NumParam::Param, long>& num_param_input,
                         const map<BoolParam::Param, bool>& bool_param_input,
                         map<PolyParam::Param, vector<string> >& poly_param_input,
-                        renf_class_shared number_field_ref,
+                        renf_class_ptr number_field_ref,
                         InputMap<InputNumberType>& add_input) {
     Output<ConeType> Out;  // all the information relevant for output is collected in this object
 
+    /*
     // const
-    renf_class_shared number_field =
+    renf_class_ptr number_field =
 #ifdef ENFNORMALIZ
         number_field_ref.get();
 #else
         number_field_ref;
 #endif
+        */
 
     options.applyOutputOptions(Out);
 
@@ -444,7 +446,7 @@ void compute_and_output(OptionsHandler& options,
     MyCone.setPolyParams(poly_param_input);
     MyCone.setNumericalParams(num_param_input);
     MyCone.setBoolParams(bool_param_input);
-    MyCone.setRenf(number_field);
+    MyCone.setRenf(number_field_ref);
     MyCone.setProjectName(options.getProjectName());
     try {
         write_fusion_mult_tables_from_input = false;
@@ -479,7 +481,7 @@ void compute_and_output(OptionsHandler& options,
     }
 
     Out.setCone(MyCone);
-    Out.set_renf(number_field);
+    Out.set_renf(number_field_ref);
 
     signal(SIGINT, SIG_DFL);
 
@@ -493,7 +495,7 @@ void compute_and_output(OptionsHandler& options,
         options.applyOutputOptions(IntHullOut);
         IntHullOut.set_name(options.getProjectName() + ".IntHull");
         IntHullOut.setCone(MyCone.getIntegerHullCone());
-        IntHullOut.set_renf(number_field, true);
+        IntHullOut.set_renf(number_field_ref, true);
         IntHullOut.write_files();
     }
 
@@ -502,7 +504,7 @@ void compute_and_output(OptionsHandler& options,
         options.applyOutputOptions(ProjOut);
         ProjOut.set_name(options.getProjectName() + ".ProjectCone");
         ProjOut.setCone(MyCone.getProjectCone());
-        ProjOut.set_renf(number_field);
+        ProjOut.set_renf(number_field_ref);
         ProjOut.write_files();
     }
 
@@ -665,7 +667,7 @@ int process_data(OptionsHandler& options, const string& command_line) {
         map<BoolParam::Param, bool> bool_param_input;
         map<PolyParam::Param, vector<string> > poly_param_input;
         bool renf_read = false;
-        renf_class_shared number_field;
+        renf_class_ptr number_field;
 
         if(!standard_fusion_name){
             try {
